@@ -136,12 +136,13 @@ class JyInterface(object):
         return float(response.message[1:-1])
     
     def getUsdt(self):
-        response = self.stub.getBalanceUsdt(common_pb2.UsdtRequest(type=self.type_,
-                                                                 appKey=self.appKey,
-                                                                 secret=self.secret,
-                                                                 passphrase=self.passphrase,
-                                                                 mark="USDT"))
-        return float(response.message)        
+        response = self.stub.getPosition(common_pb2.BalanceRequest(type=self.type_,
+                                                               appKey=self.appKey,
+                                                             secret=self.secret,
+                                                             passphrase=self.passphrase,
+                                                             futureOrSpot=self.futureOrSpot,
+                                                             mark="USDT")) 
+        return float(response.message[1:-1])       
     
     def getLastPrice(self, symbol):
         response = self.stub.getLastPrice(common_pb2.LastPriceRequest(type=self.type_, 
@@ -176,6 +177,7 @@ class JyInterface(object):
     
     def run(self, func):
         while True:
+            time.sleep(0.9)
             try:
                 tmnum = int(re.sub("\D", "", self.period))   
                 tmstr = re.sub("[0-9]", "", self.period)
